@@ -143,8 +143,7 @@ class Human(Player):
         self.emit("offer", Offer(action, param=param))
 
     # Send the player move updates
-    @asyncio.coroutine
-    def makeMove(self, board1, move, board2):
+    async def makeMove(self, board1, move, board2):
         log.debug("Human.makeMove: move=%s, board1=%s board2=%s" % (
             move, board1, board2))
         if self.board.view.premove_piece and self.board.view.premove0 and \
@@ -165,7 +164,7 @@ class Human(Player):
             self.board.view.setPremove(None, None, None, None)
         self.gmwidg.setLocked(False)
 
-        item = yield from self.move_queue.get()
+        item = await self.move_queue.get()
         self.gmwidg.setLocked(True)
 
         if item == "del":
@@ -220,6 +219,8 @@ class Human(Player):
     def playerUndoMoves(self, movecount, gamemodel):
         log.debug("Human.playerUndoMoves:  movecount=%s self=%s gamemodel.curplayer=%s" %
                   (movecount, self, gamemodel.curplayer))
+        self.gmwidg.clearMessages()
+
         # If the movecount is odd, the player has changed, and we have to interupt
         if movecount % 2 == 1 and gamemodel.curplayer != self:
             # If it is no longer us to move, we raise TurnInterruprt in order to
@@ -259,6 +260,8 @@ class Human(Player):
 
         def response_cb(infobar, response, message):
             if response == Gtk.ResponseType.ACCEPT:
+                if offer.type == TAKEBACK_OFFER:
+                    self.gamemodel.undoMoves(offer.param)
                 self.emit("accept", offer)
             elif response == Gtk.ResponseType.NO:
                 self.emit("decline", offer)
