@@ -6,9 +6,10 @@ from .Piece import Piece
 from .Cord import Cord
 from .const import A1, A8, B1, B8, C1, C8, D1, D8, E1, E8, F1, F8, G1, G8, H1, H8, \
     BISHOP, ROOK, ROOK_PROMOTION, QUEEN_PROMOTION, KNIGHT_PROMOTION, BLACK, FEN_START, \
-    WHITE, NORMALCHESS, PAWN, BISHOP_PROMOTION, KNIGHT, QUEEN, KING, DROP_VARIANTS, NULL_MOVE, \
+    WHITE, NORMALCHESS, PAWN, BISHOP_PROMOTION, KNIGHT, QUEEN, KING, DROP_VARIANTS, \
     DROP, ATOMICCHESS, ENPASSANT, FISCHERRANDOMCHESS, QUEEN_CASTLE, CRAZYHOUSECHESS, KING_CASTLE, \
-    WILDCASTLECHESS, PROMOTIONS, WILDCASTLESHUFFLECHESS, FAN_PIECES
+    WILDCASTLECHESS, PROMOTIONS, WILDCASTLESHUFFLECHESS, FAN_PIECES, \
+    GATINGS, HAWK, HAWK_GATE, ELEPHANT, HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK, SCHESS
 
 
 def reverse_enum(L):
@@ -54,7 +55,7 @@ class Board:
 
             for color in (BLACK, WHITE):
                 pieces = self.board.boards[color]
-                for piece in (PAWN, KNIGHT, BISHOP, ROOK, QUEEN, KING):
+                for piece in (PAWN, KNIGHT, BISHOP, ROOK, QUEEN, KING, HAWK, ELEPHANT):
                     for cord in iterBits(pieces[piece]):
                         self.data[RANK(cord)][FILE(cord)] = Piece(color, piece)
 
@@ -66,13 +67,17 @@ class Board:
                             self[self.newHoldingCord(color, 1)] = Piece(color,
                                                                         piece)
 
-    def getHoldingCord(self, color, piece):
+    def getHoldingCord(self, color, piece, piece_color=None):
         """Get the chord of first occurrence of piece in given color holding"""
 
         enum = reverse_enum if color == WHITE else enumerate
         for x_loc in self.HOLDING_FILES[color]:
             for y_loc, row in enum(self.data):
                 if (row.get(x_loc) is not None) and row.get(x_loc).piece == piece:
+                    # In S-chess holding may contain our un-gated and captured H/E at the same time
+                    # but in case of gating we are looking for our own HAWK/ELEPHANT only!
+                    if piece_color is not None and row.get(x_loc).color != piece_color:
+                        continue
                     return Cord(x_loc, y_loc)
 
     def newHoldingCord(self, color, nth=1):
@@ -127,12 +132,14 @@ class Board:
         new = []
         dead = []
 
-        if move.flag == NULL_MOVE:
+        cord0, cord1 = move.cords
+        flag = FLAG(move.move)
+
+        # null move or SITTUYINCHESS in place promotion
+        if cord0 == cord1 and flag != DROP and flag != QUEEN_PROMOTION:
             return moved, new, dead
 
-        cord0, cord1 = move.cords
-
-        if move.flag == DROP:
+        if flag == DROP:
             piece = FCORD(move.move)
             cord0 = self.getHoldingCord(self.color, piece)
             moved.append((self[cord0], cord0))
@@ -141,8 +148,13 @@ class Board:
             dead = new
             return moved, new, dead
 
+        kcastle = flag == KING_CASTLE or (
+            self.variant == SCHESS and ((self[move.cord0].piece == KING and cord0.x - cord1.x == -2) or (flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK) and cord0.x - cord1.x > 0)))
+        qcastle = flag == QUEEN_CASTLE or (
+            self.variant == SCHESS and ((self[move.cord0].piece == KING and cord0.x - cord1.x == 2) or (flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK) and cord0.x - cord1.x < 0)))
+
         if self.variant == ATOMICCHESS and (self[cord1] or
-                                            move.flag == ENPASSANT):
+                                            flag == ENPASSANT):
             # Sequence nubers of next newHoldingCord of WHITE and BLACK
             nth = [0, 0]
 
@@ -152,13 +164,13 @@ class Board:
             moved.append((board1[cord], cord0))
             new.append(board1[cord])
         else:
-            if move.flag in PROMOTIONS:
+            if flag in PROMOTIONS:
                 dead.append(self[cord0])
             else:
                 moved.append((self[cord0], cord0))
 
-        if self[cord1] and not (self.variant == FISCHERRANDOMCHESS and
-                                move.flag in (QUEEN_CASTLE, KING_CASTLE)):
+        # capture
+        if self[cord1] and not (flag in (QUEEN_CASTLE, KING_CASTLE, HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK)):
             piece = PAWN if self.variant == CRAZYHOUSECHESS and self[
                 cord1].promoted else self[cord1].piece
             cord = board1.getHoldingCord(self.color, piece)
@@ -178,26 +190,33 @@ class Board:
                         moved.append((board1[cord], acord))
                         new.append(board1[cord])
 
-        if move.flag in (QUEEN_CASTLE, KING_CASTLE):
-            side = move.flag - QUEEN_CASTLE
+        if kcastle or qcastle:
+            side = 0 if qcastle else 1
             if FILE(cord0.x) == 3 and self.board.variant in (
                     WILDCASTLECHESS, WILDCASTLESHUFFLECHESS):
                 side = 0 if side == 1 else 1
             rook = self.board.ini_rooks[self.color][side]
             moved.append((self[Cord(rook)], Cord(rook)))
 
-        elif move.flag in PROMOTIONS:
+        elif flag in PROMOTIONS:
             newPiece = board1[cord1]
             moved.append((newPiece, cord0))
             new.append(newPiece)
 
-        elif move.flag == ENPASSANT:
+        elif flag == ENPASSANT:
             shift = -1 if self.color == WHITE else 1
             ep_cord = Cord(cord1.x, cord1.y + shift)
             moved.append((self[ep_cord], ep_cord))
             # add all captured pieces to "new" list to enforce repainting them after a possible reordering
             new = board1.getHoldingPieces(self.color)
 
+        if flag in GATINGS:
+            gpiece = HAWK if flag in (HAWK_GATE, HAWK_GATE_AT_ROOK) else ELEPHANT
+            cord0 = self.getHoldingCord(self.color, gpiece)
+            moved.append((self[cord0], cord0))
+            # add all captured pieces to "new" list to enforce repainting them after a possible reordering
+            new = board1.getHoldingPieces(self.color)
+
         return moved, new, dead
 
     def simulateUnmove(self, board1, move):
@@ -205,24 +224,35 @@ class Board:
         new = []
         dead = []
 
-        if move.flag == NULL_MOVE:
+        cord0, cord1 = move.cords
+        flag = FLAG(move.move)
+
+        # null move or SITTUYINCHESS in place promotion
+        if cord0 == cord1 and flag != DROP and flag != QUEEN_PROMOTION:
             return moved, new, dead
 
-        cord0, cord1 = move.cords
-
         if self.variant == ATOMICCHESS and (board1[cord1] or
-                                            move.flag == ENPASSANT):
+                                            flag == ENPASSANT):
             piece = board1[cord0].piece
             cord = self.getHoldingCord(self.color, piece)
             moved.append((self[cord], cord))
             self[cord].opacity = 1
             dead.append(self[cord])
-        elif not (self.variant == FISCHERRANDOMCHESS and move.flag in
+        elif not (self.variant == FISCHERRANDOMCHESS and flag in
                   (QUEEN_CASTLE, KING_CASTLE)):
             moved.append((self[cord1], cord1))
 
-        if board1[cord1] and not (self.variant == FISCHERRANDOMCHESS and
-                                  move.flag in (QUEEN_CASTLE, KING_CASTLE)):
+        kcastle = flag == KING_CASTLE or (
+            self.variant == SCHESS and (
+                (self[move.cord1] is not None and self[move.cord1].piece == KING and cord0.x - cord1.x == -2) or
+                (flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK) and cord0.x - cord1.x > 0)))
+        qcastle = flag == QUEEN_CASTLE or (
+            self.variant == SCHESS and (
+                (self[move.cord1] is not None and self[move.cord1].piece == KING and cord0.x - cord1.x == 2) or
+                (flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK) and cord0.x - cord1.x < 0)))
+
+        # capture
+        if board1[cord1] and not (flag in (QUEEN_CASTLE, KING_CASTLE, HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK)):
             piece = PAWN if self.variant == CRAZYHOUSECHESS and board1[
                 cord1].promoted else board1[cord1].piece
             cord = self.getHoldingCord(1 - self.color, piece)
@@ -244,20 +274,20 @@ class Board:
                         self[cord].opacity = 1
                         dead.append(self[cord])
 
-        if move.flag in (QUEEN_CASTLE, KING_CASTLE):
-            side = move.flag - QUEEN_CASTLE
+        if kcastle or qcastle:
+            side = 0 if qcastle else 1
             if FILE(cord0.x) == 3 and self.board.variant in (
                     WILDCASTLECHESS, WILDCASTLESHUFFLECHESS):
                 side = 0 if side == 1 else 1
             rook = self.board.fin_rooks[board1.color][side]
             moved.append((self[Cord(rook)], Cord(rook)))
 
-        elif move.flag in PROMOTIONS:
+        elif flag in PROMOTIONS:
             newPiece = board1[cord0]
             moved.append((newPiece, cord1))
             new.append(newPiece)
 
-        elif move.flag == ENPASSANT:
+        elif flag == ENPASSANT:
             cord = self.getHoldingCord(1 - self.color, PAWN)
             moved.append((self[cord], cord))
             self[cord].opacity = 1
@@ -265,6 +295,10 @@ class Board:
             new = self.getHoldingPieces(self.color)
             dead.append(self[cord])
 
+        elif flag in GATINGS:
+            # add all gated pieces to "new" list to enforce repainting them after a possible reordering
+            new = self.getHoldingPieces(1 - self.color)
+
         return moved, new, dead
 
     def move(self, move, lboard=None):
@@ -284,11 +318,20 @@ class Board:
         newBoard = self.clone(lboard=lboard)
         if lboard is None:
             newBoard.board.applyMove(move.move)
-
         cord0, cord1 = move.cords
 
+        kcastle = flag == KING_CASTLE or (
+            self.variant == SCHESS and ((self[move.cord0].piece == KING and cord0.x - cord1.x == -2) or (flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK) and cord0.x - cord1.x > 0)))
+        qcastle = flag == QUEEN_CASTLE or (
+            self.variant == SCHESS and ((self[move.cord0].piece == KING and cord0.x - cord1.x == 2) or (flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK) and cord0.x - cord1.x < 0)))
+
+        if kcastle or qcastle:
+            gcord = cord0  # save gating cord
+
+        # capture
         if (self[move.cord1] is not None or flag == ENPASSANT) and \
-                not (flag in (QUEEN_CASTLE, KING_CASTLE)):
+                not (cord0 == cord1 and flag != DROP and flag != QUEEN_PROMOTION) and \
+                not (kcastle or qcastle):
             if self.variant == CRAZYHOUSECHESS:
                 piece = PAWN if flag == ENPASSANT or self[
                     move.cord1].promoted else self[move.cord1].piece
@@ -333,16 +376,19 @@ class Board:
                     1 - self.color])] = new_piece
                 newBoard[cord1] = None
             else:
-                if flag in (QUEEN_CASTLE, KING_CASTLE):
-                    king = newBoard[cord0]
+                if kcastle or qcastle:
+                    if flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK):
+                        king = newBoard[cord1]
+                    else:
+                        king = newBoard[cord0]
                 else:
                     newBoard[cord1] = newBoard[cord0]
 
-        if flag != NULL_MOVE and flag != DROP:
+        if cord0 != cord1 and flag != DROP and flag != HAWK_GATE_AT_ROOK and flag != ELEPHANT_GATE_AT_ROOK:
             newBoard[cord0] = None
 
-        if flag in (QUEEN_CASTLE, KING_CASTLE):
-            side = flag - QUEEN_CASTLE
+        if kcastle or qcastle:
+            side = 0 if qcastle else 1
             if FILE(cord0.x) == 3 and self.board.variant in (
                     WILDCASTLECHESS, WILDCASTLESHUFFLECHESS):
                 side = 0 if side == 1 else 1
@@ -351,9 +397,17 @@ class Board:
             newBoard[Cord(finrook)] = newBoard[Cord(inirook)]
             if inirook != finrook:
                 newBoard[Cord(inirook)] = None
+            if flag in (HAWK_GATE_AT_ROOK, ELEPHANT_GATE_AT_ROOK):
+                newBoard[cord1] = None
             finking = self.board.fin_kings[self.color][side]
             newBoard[Cord(finking)] = king
 
+        if flag in GATINGS:
+            gpiece = HAWK if flag in (HAWK_GATE, HAWK_GATE_AT_ROOK) else ELEPHANT
+            holding_coord = self.getHoldingCord(self.color, gpiece, piece_color=self.color)
+            newBoard[gcord if (kcastle or qcastle) else cord0] = newBoard[holding_coord]
+            newBoard[holding_coord] = None
+
         if flag in PROMOTIONS:
             new_piece = Piece(self.color, PROMOTE_PIECE(flag))
             new_piece.promoted = True
@@ -364,6 +418,7 @@ class Board:
 
         if flag == DROP or flag == ENPASSANT or self[move.cord1] is not None:
             newBoard.reorderHolding(self.color)
+
         return newBoard
 
     def switchColor(self):
