@@ -1,4 +1,3 @@
-import asyncio
 import collections
 import re
 
@@ -7,7 +6,7 @@ from pychess.ic import BLOCK_START, BLOCK_SEPARATOR, BLOCK_END, BLKCMD_PASSWORD
 from pychess.ic.icc import UNIT_START, UNIT_END, DTGR_START, MY_ICC_PREFIX
 
 
-class ConsoleHandler(object):
+class ConsoleHandler:
     def __init__(self, callback):
         self.callback = callback
 
@@ -16,7 +15,7 @@ class ConsoleHandler(object):
             self.callback(line)
 
 
-class Prediction(object):
+class Prediction:
     def __init__(self, callback, *regexps):
         self.callback = callback
         self.name = callback.__name__
@@ -164,7 +163,7 @@ TelnetLine = collections.namedtuple('TelnetLine', ['line', 'code', 'code_type'])
 EmptyTelnetLine = TelnetLine("", None, None)
 
 
-class TelnetLines(object):
+class TelnetLines:
     def __init__(self, telnet, show_reply):
         self.telnet = telnet
         self.lines = collections.deque()
@@ -180,19 +179,17 @@ class TelnetLines(object):
     def extendleft(self, iterable):
         self.lines.extendleft(iterable)
 
-    @asyncio.coroutine
-    def popleft(self):
+    async def popleft(self):
         try:
             return self.lines.popleft()
         except IndexError:
-            lines = yield from self._get_lines()
+            lines = await self._get_lines()
             self.lines.extend(lines)
             return self.lines.popleft() if self.lines else EmptyTelnetLine
 
-    @asyncio.coroutine
-    def _get_lines(self):
+    async def _get_lines(self):
         lines = []
-        line = yield from self.telnet.readline()
+        line = await self.telnet.readline()
         identifier = 0
 
         if line.startswith(self.line_prefix):
@@ -208,7 +205,7 @@ class TelnetLines(object):
                 cn_code = int(line[2:line.find(" ")])
                 if MY_ICC_PREFIX in line:
                     identifier = 0
-                line = yield from self.telnet.readline()
+                line = await self.telnet.readline()
 
             if unit:
                 while UNIT_END not in line:
@@ -223,7 +220,7 @@ class TelnetLines(object):
                                 unit_lines.append(parts[0])
                         else:
                             unit_lines.append(line)
-                    line = yield from self.telnet.readline()
+                    line = await self.telnet.readline()
                 if len(unit_lines) > 0:
                     text = "\n".join(unit_lines)
                     lines.append(TelnetLine(text, cn_code, CN))
@@ -244,11 +241,11 @@ class TelnetLines(object):
             if text:
                 line = text
             else:
-                line = yield from self.telnet.readline()
+                line = await self.telnet.readline()
 
             while not line.endswith(BLOCK_END):
                 lines.append(TelnetLine(line, code, BL))
-                line = yield from self.telnet.readline()
+                line = await self.telnet.readline()
             lines.append(TelnetLine(line[:-1], code, BL))
 
             if code != BLKCMD_PASSWORD:
@@ -268,7 +265,7 @@ class TelnetLines(object):
         return lines
 
 
-class PredictionsTelnet(object):
+class PredictionsTelnet:
     def __init__(self, telnet, predictions, reply_cmd_dict, replay_dg_dict, replay_cn_dict):
         self.telnet = telnet
         self.predictions = predictions
@@ -279,9 +276,8 @@ class PredictionsTelnet(object):
         self.lines = TelnetLines(telnet, self.show_reply)
         self.__command_id = 1
 
-    @asyncio.coroutine
-    def parse(self):
-        line = yield from self.lines.popleft()
+    async def parse(self):
+        line = await self.lines.popleft()
 
         if not line.line:
             return  # TODO: necessary?
@@ -301,7 +297,7 @@ class PredictionsTelnet(object):
         predictions = self.reply_cmd_dict[line.code] \
             if line.code is not None and line.code in self.reply_cmd_dict else self.predictions
         for pred in list(predictions):
-            answer = yield from self.test_prediction(pred, line)
+            answer = await self.test_prediction(pred, line)
             # print(answer, "  parse_line: trying prediction %s for line '%s'" % (pred.name, line.line[:80]))
             if answer in (RETURN_MATCH, RETURN_MATCH_END):
                 log.debug("\n".join(pred.matches),
@@ -313,12 +309,11 @@ class PredictionsTelnet(object):
                 log.debug(line.line,
                           extra={"task": (self.telnet.name, "nonmatched")})
 
-    @asyncio.coroutine
-    def test_prediction(self, prediction, line):
+    async def test_prediction(self, prediction, line):
         lines = []
         answer = prediction.handle(line.line)
         while answer is RETURN_NEED_MORE:
-            line = yield from self.lines.popleft()
+            line = await self.lines.popleft()
             lines.append(line)
             answer = prediction.handle(line.line)
 
