@@ -47,7 +47,7 @@ IC_STATUS_PLAYING, IC_STATUS_ACTIVE, IC_STATUS_BUSY, IC_STATUS_OFFLINE, \
     IC_STATUS_IDLE, IC_STATUS_IN_TOURNAMENT, IC_STATUS_RUNNING_SIMUL_MATCH, \
     IC_STATUS_UNKNOWN = range(11)
 
-TITLES_RE = "(?:\([A-Z*]+\))*"
+TITLES_RE = r"(?:\([A-Z*]+\))*"
 NAMES_RE = "[A-Za-z]+"
 
 DEVIATION = {
@@ -68,7 +68,7 @@ STATUS = {
 }
 
 
-class GameType(object):
+class GameType:
     def __init__(self,
                  fics_name,
                  short_fics_name,
