@@ -7,7 +7,7 @@ TYPE_PERSONAL, TYPE_CHANNEL, TYPE_GUEST, \
 
 
 def get_playername(playername):
-    re_m = re.match("(\w+)\W*", playername)
+    re_m = re.match(r"(\w+)\W*", playername)
     return re_m.groups()[0]
 
 
@@ -63,7 +63,7 @@ class BulletCellRenderer(Gtk.CellRenderer):
 GObject.type_register(BulletCellRenderer)
 
 
-class Panel(object):
+class Panel:
     def start(self):
         pass
 
